pub trait CacheTrait:
'static
+ Send
+ Sync
+ Any {
// Required methods
fn update(&mut self);
fn len(&self) -> usize;
}Expand description
A cache, storing some value for some length of time.
pub trait CacheTrait:
'static
+ Send
+ Sync
+ Any {
// Required methods
fn update(&mut self);
fn len(&self) -> usize;
}A cache, storing some value for some length of time.